.. _scalars:

=============================
Strings, Numbers and Booleans
=============================

.. currentmodule:: flatland.schema.scalars


Strings
-------

.. autoclass:: String


Numbers
-------

.. autoclass:: Integer

.. autoclass:: Long

.. autoclass:: Float

.. autoclass:: Decimal


Booleans
--------

.. autoclass:: Boolean
